@@ -96,8 +96,8 @@ alba3 <- ELEFAN_SA(
   low_par = list(Linf=PW$confidenceInt_Linf[1], K=1, t_anchor=0, ts=0, C=0),
   up_par = list(Linf=PW$confidenceInt_Linf[2], K=4, t_anchor=1, ts=1, C=1),
   SA_temp = 2e5,
-  SA_time = 60,
-  maxit = 400,
+  SA_time = 60 * 0.5, ## 60
+  maxit = 100, ## 400
   MA = 7,
   plot.score = TRUE,
   verbose = FALSE
@@ -117,7 +117,7 @@ alba4 <- ELEFAN_GA(
   up_par = list(Linf=PW$confidenceInt_Linf[2], K=4, t_anchor=1, ts=1, C=1),
   popSize = 60,
   pmutation = 0.2,
-  maxiter = 100,
+  maxiter = 50, ## 100
   run = 20,
   MA = 7,
   plot.score = TRUE,
@@ -139,7 +139,7 @@ alba5 <- ELEFAN_GA(
   up_par = list(Linf=PW$confidenceInt_Linf[2], K=4, t_anchor=1, ts=1, C=1),
   popSize = 60,
   pmutation = 0.2,
-  maxiter = 100,
+  maxiter = 50, ## 100
   run = 20,
   MA = 7,
   plot.score = TRUE,
@@ -155,6 +155,7 @@ true_par <- list(Linf = 80, K = 0.5, t_anchor = 0.25,C = 0.75,  ts = 0.5, phiL =
 
 ## -----------------------------------------------------------------------------
 set.seed(1)
+data("synLFQ4")
 synLFQ4 <- ELEFAN_GA(
   lfq = synLFQ4,
   seasonalised = TRUE,
@@ -162,7 +163,7 @@ synLFQ4 <- ELEFAN_GA(
   up_par = list(Linf=110, K=1, t_anchor=1, ts=1, C=1),
   popSize = 60,
   pmutation = 0.2,
-  maxiter = 100,
+  maxiter = 50, ## 100
   run = 20,
   MA = 11,
   plot.score = TRUE,
@@ -191,7 +192,7 @@ synLFQ4 <- ELEFAN_GA(
   up_par = list(Linf=110, K=1, t_anchor=1, ts=1, C=1),
   popSize = 60,
   pmutation = function(...) GA::ga_pmutation(..., p0=0.5, p=0.1),
-  maxiter = 100,
+  maxiter = 50, ## 100
   run = 20,
   MA = 11,
   plot.score = TRUE,
